@@ -1,20 +1,16 @@
-serialization_rules = []
+from collections import deque
+
+
+serialization_rules = deque()
 
 
 def serialize(obj):
-    for rule in serialization_rules:
-        if rule.is_applicable_for_serialization(obj):
-            return rule.serialize(obj)
-
-    return obj
+    return next((rule.serialize(obj) for rule in serialization_rules if rule.is_applicable_for_serialization(obj)), obj)
 
 
 def deserialize(obj):
-    for rule in serialization_rules:
-        if rule.is_applicable_for_deserialization(obj):
-            return rule.deserialize(obj)
-
-    return obj
+    return next((rule.deserialize(obj) for rule in serialization_rules if rule.is_applicable_for_deserialization(obj)),
+                obj)
 
 
 def nox_serializer(serializer):
@@ -23,7 +19,6 @@ def nox_serializer(serializer):
 
 
 class BaseSerializationRule(object):
-
     def is_applicable_for_serialization(self, obj):
         raise NotImplementedError
 
@@ -35,3 +30,19 @@ class BaseSerializationRule(object):
 
     def deserialize(self, obj):
         raise NotImplementedError
+
+
+class IterableSerializationRule(BaseSerializationRule):
+    def is_applicable_for_serialization(self, obj):
+        return False
+
+    def is_applicable_for_deserialization(self, obj):
+        return isinstance(obj, (list, tuple, set))
+
+    def serialize(self, obj):
+        raise NotImplementedError
+
+    def deserialize(self, obj):
+        return map(deserialize, obj)
+
+nox_serializer(IterableSerializationRule())
